# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 63.1.2-v202405160133
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class EmailNotificationRecipientOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'email_address': 'str',
        'identity_id': 'str',
        'name': 'str',
        'redacted': 'bool'
    }

    attribute_map = {
        'email_address': 'emailAddress',
        'identity_id': 'identityId',
        'name': 'name',
        'redacted': 'redacted'
    }

    def __init__(self, email_address=None, identity_id=None, name=None, redacted=None):
        """
        EmailNotificationRecipientOutputV1 - a model defined in Swagger
        """

        self._email_address = None
        self._identity_id = None
        self._name = None
        self._redacted = None

        if email_address is not None:
          self.email_address = email_address
        if identity_id is not None:
          self.identity_id = identity_id
        if name is not None:
          self.name = name
        if redacted is not None:
          self.redacted = redacted

    @property
    def email_address(self):
        """
        Gets the email_address of this EmailNotificationRecipientOutputV1.

        :return: The email_address of this EmailNotificationRecipientOutputV1.
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """
        Sets the email_address of this EmailNotificationRecipientOutputV1.

        :param email_address: The email_address of this EmailNotificationRecipientOutputV1.
        :type: str
        """

        self._email_address = email_address

    @property
    def identity_id(self):
        """
        Gets the identity_id of this EmailNotificationRecipientOutputV1.

        :return: The identity_id of this EmailNotificationRecipientOutputV1.
        :rtype: str
        """
        return self._identity_id

    @identity_id.setter
    def identity_id(self, identity_id):
        """
        Sets the identity_id of this EmailNotificationRecipientOutputV1.

        :param identity_id: The identity_id of this EmailNotificationRecipientOutputV1.
        :type: str
        """

        self._identity_id = identity_id

    @property
    def name(self):
        """
        Gets the name of this EmailNotificationRecipientOutputV1.

        :return: The name of this EmailNotificationRecipientOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this EmailNotificationRecipientOutputV1.

        :param name: The name of this EmailNotificationRecipientOutputV1.
        :type: str
        """

        self._name = name

    @property
    def redacted(self):
        """
        Gets the redacted of this EmailNotificationRecipientOutputV1.

        :return: The redacted of this EmailNotificationRecipientOutputV1.
        :rtype: bool
        """
        return self._redacted

    @redacted.setter
    def redacted(self, redacted):
        """
        Sets the redacted of this EmailNotificationRecipientOutputV1.

        :param redacted: The redacted of this EmailNotificationRecipientOutputV1.
        :type: bool
        """

        self._redacted = redacted

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, EmailNotificationRecipientOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
